<?php declare(strict_types=1);

namespace App\Entity;

use App\Repository\BrandRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'brand', schema: 'collection')]
#[ORM\Entity]
class Brand
{
    use GetSetTrait;

    #[ORM\Column(name: 'id', type: 'integer', nullable: FALSE)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'IDENTITY')]
    #[ORM\SequenceGenerator(sequenceName: 'brand_id_seq', allocationSize: 1, initialValue: 1)]
    private int $id;

	#[ORM\ManyToMany(targetEntity: BrandCategory::class)]
	#[ORM\JoinTable(name: 'collection.brand_category_link')]
	#[ORM\JoinColumn(name: 'brand_id', referencedColumnName: 'id')]
	#[ORM\InverseJoinColumn(name: 'brand_category', referencedColumnName: 'category_name')]
	#[ORM\OrderBy(['name' => 'asc'])]
	private $categories;

    #[ORM\Column(name: 'name', unique: TRUE, nullable: FALSE)]
    private string $name;

    public function __construct()
    {
        $this->categories = new ArrayCollection();
    }

    public function __toString(): string
    {
        return $this->name;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    /**
     * @return Collection<int, BrandCategory>
     */
    public function getCategories(): Collection
    {
        return $this->categories;
    }

    public function addCategory(BrandCategory $category): self
    {
        if (!$this->categories->contains($category)) {
            $this->categories->add($category);
        }

        return $this;
    }

    public function removeCategory(BrandCategory $category): self
    {
        $this->categories->removeElement($category);

        return $this;
    }
}
