<?php declare(strict_types=1);

namespace App\Entity;

use App\Enum\CardBusEnum;
use App\Enum\SlotKeyEnum;
use App\Types\CardBusEnumType;
use App\Types\SlotKeyEnumType;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'gpu', schema: 'collection')]
#[ORM\Entity]
class Gpu
{
    use GetSetTrait;

    #[ORM\Column(name: 'id', type: 'integer', nullable: FALSE)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'IDENTITY')]
    private int $id;

    #[ORM\ManyToOne(targetEntity: 'Brand')]
    #[ORM\OrderBy(['name' => 'asc'])]
    #[ORM\JoinColumn(name: 'gpu_brand_id', referencedColumnName: 'id', nullable: FALSE)]
    private Brand $gpuBrand;

    #[ORM\ManyToOne(targetEntity: 'GpuCore')]
    #[ORM\OrderBy(['brand' => 'asc', 'name' => 'asc'])]
    #[ORM\JoinColumn(name: 'gpu_core_id', referencedColumnName: 'id', nullable: TRUE)]
    private ?GpuCore $gpuCore = null;

    #[ORM\Column(name: 'reference_model_name', nullable: FALSE)]
    private string $modelName;

    #[ORM\ManyToOne(targetEntity: 'Brand')]
	#[ORM\OrderBy(['name' => 'asc'])]
	#[ORM\JoinColumn(name: 'board_brand_id', referencedColumnName: 'id', nullable: TRUE)]
	private ?Brand $boardBrand = NULL;

    #[ORM\Column(name: 'alternate_model_name', nullable: TRUE)]
    private ?string $alternateModelName = '';

    #[ORM\Column(name: 'card_key', type: SlotKeyEnumType::NAME, nullable: TRUE, enumType: SlotKeyEnum::class)]
    private SlotKeyEnum $cardKey = SlotKeyEnum::PCIE_X16;

    #[ORM\Column(name: 'bus_interface', type: CardBusEnumType::NAME, nullable: TRUE, enumType: CardBusEnum::class)]
	private ?CardBusEnum $busInterface;

    #[ORM\Column(name: 'slot_width')]
	private int $slotWidth = 1;

    #[ORM\Column(name: 'molex_power')]
	private int $molexPower = 0;

    #[ORM\Column(name: 'pcie_6_pin')]
	private int $pcie6power = 0;

    #[ORM\Column(name: 'pcie_8_pin')]
	private int $pcie8power = 0;

    #[ORM\Column(name: 'tdp', nullable: TRUE)]
    private ?int $tdp = 0;

    #[ORM\Column(name: 'base_clock', nullable: TRUE)]
	private ?int $baseClock;

    #[ORM\Column(name: 'boost_clock', nullable: TRUE)]
	private ?int $boostClock;

    #[ORM\Column(name: 'memory_clock', nullable: TRUE)]
	private ?int $memoryClock;

    #[ORM\Column(name: 'memory_size', nullable: TRUE)]
	private ?int $memorySize;

    #[ORM\Column(name: 'memory_bus', nullable: TRUE)]
	private ?int $memoryBus;

    #[ORM\Column(name: 'memory_type', nullable: TRUE)]
	private ?string $memoryType;

    #[ORM\Column(name: 'shading_units', nullable: TRUE)]
	private ?int $shadingUnits;

    #[ORM\Column(name: 'tmus', nullable: TRUE)]
	private ?int $tmus;

    #[ORM\Column(name: 'rops', nullable: TRUE)]
	private ?int $rops;

    #[ORM\Column(name: 'compute_units', nullable: TRUE)]
	private ?int $computeUnits;

    #[ORM\Column(name: 'l1_cache', nullable: TRUE)]
	private ?string $l1cache;

    #[ORM\Column(name: 'l2_cache', nullable: TRUE)]
	private ?string $l2cache;

    #[ORM\Column(name: 'direct_x_support', nullable: TRUE)]
	private ?string $directXSupport;

    #[ORM\Column(name: 'opengl_support', nullable: TRUE)]
	private ?string $openGLSupport;

    #[ORM\Column(name: 'opencl_support', nullable: TRUE)]
	private ?string $openCLSupport;

    #[ORM\Column(name: 'vulkan_support', nullable: TRUE)]
	private ?string $vulkanSupport;

    #[ORM\Column(name: 'shader_model', nullable: TRUE)]
	private ?string $shaderModel;

    #[ORM\Column(name: 'link')]
    private readonly string $link;

    #[ORM\Column(name: 'count', nullable: FALSE)]
    private int $count = 1;

    #[ORM\Column(name: 'acquired')]
	private bool $acquired;

    #[ORM\Column(name: 'notes', type: 'text', nullable: TRUE)]
    private ?string $notes = '';
}
